@@ -2,7 +2,7 @@
 function blog_postlist_render() {
 	$blog_page_url = getconfig ( "blog_page_url" );
 	if (! $blog_page_url) {
-		return '<p class="ulicms_error">Bitte setzen Sie die Konfigurationsvariable blog_page_url';
+		return '<p class="ulicms-error">Bitte setzen Sie die Konfigurationsvariable blog_page_url';
 	}
 	
 	$sql = db_query ( "SELECT title, seo_shortname FROM " . tbname ( "blog" ) . " WHERE entry_enabled = 1 and language ='" . $_SESSION ["language"] . "' order by datum DESC" );
